@@ -6,8 +6,6 @@ import logging
 import os
 import pathlib
 import warnings
-from datetime import datetime
-from decimal import *
 
 try:
     from importlib.resources import files
@@ -93,8 +91,8 @@ def read_excel_file(
         for column_index in range(len(row)):
             column = excel_defination_columns[column_index]
             story.set_value(column[2], column[1], row[column_index].value)
-            if column[1] is Milestone:
-                story[column[2]].calc_priority(sprint_schedule)
+            if column[2] is Milestone:
+                story[column[1]].calc_priority(sprint_schedule)
         stories.append(story)
 
     wb.close()
@@ -113,7 +111,7 @@ def _should_skip(row: list) -> bool:
 
 def output_to_csv_file(
     file: str,
-    stories: 'list[Story]',
+    stories: "list[Story]",
     over_write: bool = True,
 ):
     if file is None or not pathlib.Path(file).is_absolute():
@@ -134,9 +132,9 @@ def output_to_csv_file(
 
 def output_to_excel_file(
     file: str,
-    stories: 'list[Story]',
+    stories: "list[Story]",
     excel_defination: ExcelDefination,
-    columns_in_excel: 'list[str]' = None,
+    columns_in_excel: "list[str]" = None,
     over_write: bool = True,
 ):
     """
@@ -213,13 +211,12 @@ def process_excel_file(
     :parm over_write:
         Whether or not the exist output file will be over-write.
     """
-    logger = logging.getLogger(__name__)
     sprint_schedule = SprintScheduleStore()
     if sprint_schedule_config is None:
         sprint_schedule.load(
             files("jira_tool.assets").joinpath("sprint_schedule.json").read_text()
         )
-        logger.info("Loading default sprint schedule...")
+        print("Loading default sprint schedule...")
     else:
         sprint_schedule.load_file(sprint_schedule_config)
 
@@ -228,7 +225,7 @@ def process_excel_file(
         excel_defination.load(
             files("jira_tool.assets").joinpath("excel_defination.json").read_text()
         )
-        logger.info("Loading default excel defination...")
+        print("Loading default excel defination...")
     else:
         excel_defination.load_file(excel_defination_config)
 
@@ -236,13 +233,17 @@ def process_excel_file(
         input_file, excel_defination, sprint_schedule
     )
 
+    if stories is None:
+        print("There are no stories inside the excel file.")
+        return
+
     stories = sorted(stories, reverse=True)
     sort_stories(stories, excel_defination)
-    stories = raise_story_sequence_by_property(stories, "override")
-    stories = raise_story_sequence_by_property(stories, "deferred")
+    # stories = raise_story_sequence_by_property(stories, "override")
+    # stories = raise_story_sequence_by_property(stories, "deferred")
 
     output_to_excel_file(
         output_file, stories, excel_defination, excel_columns, over_write
     )
 
-    logger.info("%s has been saved.", output_file)
+    print("%s has been saved.", output_file)
